// -*- Mode: C++; tab-width: 2; -*-
// vi: set ts=2:
//
// ==========================================================================
//
// IMPORTANT:
// This is config.h / config.h.in
// Please do ONLY change config.h.in, as config.h is automagically
// created by CMAKE from config.h.in
// 
// Use appropriate options to configure instead of changing config.h.
// Changes made in config.h will be lost as soon as you call CMAKE again.
//
// ==========================================================================
// 
// --------------------------------------------------------------------------
//                   OpenMS Mass Spectrometry Framework 
// --------------------------------------------------------------------------
//  Copyright (C) 2003-2011 -- Oliver Kohlbacher, Knut Reinert
//
//  This library is free software; you can redistribute it and/or
//  modify it under the terms of the GNU Lesser General Public
//  License as published by the Free Software Foundation; either
//  version 2.1 of the License, or (at your option) any later version.
//
//  This library is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
//  Lesser General Public License for more details.
//
//  You should have received a copy of the GNU Lesser General Public
//  License along with this library; if not, write to the Free Software
//  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
// --------------------------------------------------------------------------
// $Maintainer: Chris Bielow $
// $Authors: $
// --------------------------------------------------------------------------

#ifndef OPENMS_CONFIG_H
#define OPENMS_CONFIG_H

// Here are some global configuration flags for OpenMS

// The path to the directory where OpenMS data is installed
#define OPENMS_DATA_PATH "/usr/share/openms-common/OpenMS/"

// The path to the directory where OpenMS doc is installed
#define OPENMS_DOC_PATH "/usr/share/doc/openms-doc/"

// The directory where OpenMS is build
#define OPENMS_SOURCE_PATH "/build/buildd/openms-1.9.0"

// The directory where the OpenMS sources are located
#define OPENMS_BINARY_PATH "/build/buildd/openms-1.9.0/debian/build"

// do we use SVN revision in VersionInfo.C?! [depending on the availability of svnversion(.exe)]
/* #undef OPENMS_HAS_SVNVERSION */

// Define compiler specifics (used in VERY few places only)
// Microsoft Visual Studio .NET, 2005, 2008
/* #undef OPENMS_COMPILER_MSVC */
// GNU g++
#define OPENMS_COMPILER_GXX

// __PRETTY_FUNCTION__ is a GNU G++ extension.  It is used in exceptions to indicate their origin.
#ifndef OPENMS_COMPILER_GXX 
#define __PRETTY_FUNCTION__ "<unknown>"
#endif


// OPENMS_ASSERTIONS enables some debugging methods within some OpenMS classes
#ifdef OPENMS_COMPILER_MSVC
// we define this using NDEBUG on MSVC as there are multiple build types simultaneously in the Solution file,
// thus setting one value will not fit them all
#	ifndef NDEBUG // hopefully defined automatically by MS-compiler in Debug Mode
#		define OPENMS_ASSERTIONS
#	endif
#else // linux & Co (only one build type at a time)
#  if (0)
#    define OPENMS_ASSERTIONS
#  endif
#endif


// let Cmake decide if we are using Windows (ie if windows.h is available). 
//   GCC and MSVC have pre-defined macros for this as well but using -ansi in GCC will disable those, thus asking the compiler is fragile
#ifndef WIN32  //avoid warning of redefinition
/* #undef WIN32 */
#endif

#ifdef WIN32   //should be true on: MinGW (32bit + 64bit) & MSVS compiler
#define OPENMS_WINDOWSPLATFORM 1
#endif

// are we building a shared lib?
#define BUILD_SHARED_LIBS

#ifdef OPENMS_WINDOWSPLATFORM
# ifdef BUILD_SHARED_LIBS
#  if defined OpenMS_EXPORTS  //automatically defined by CMake when building OpenMS dll
#    define OPENMS_DLLAPI  __declspec( dllexport )
#  else
#    define OPENMS_DLLAPI  __declspec( dllimport )
#  endif
#  if defined OpenMS_GUI_EXPORTS  //automatically defined by CMake when building OpenMS-GUI dll
#    define OPENMS_GUI_DLLAPI  __declspec( dllexport )
#  else
#    define OPENMS_GUI_DLLAPI  __declspec( dllimport )
#  endif
# endif
#endif
#ifndef OPENMS_DLLAPI //leave empty when not building DLL
# define OPENMS_DLLAPI
#endif
#ifndef OPENMS_GUI_DLLAPI //leave empty when not building DLL
# define OPENMS_GUI_DLLAPI
#endif


#define OPENMS_BIG_ENDIAN

// Define on 64 bit architectures
/* #undef OPENMS_64BIT_ARCHITECTURE */

#define OPENMS_INT32_TYPE int32_t
#define OPENMS_INT64_TYPE int64_t
#define OPENMS_BYTE_TYPE uint8_t
#define OPENMS_UINT64_TYPE uint64_t
//#define OPENMS_SIZE_T_SIGNED 


// if you ever want to do abs() or floor() on this type in VC then use _abs64() and include <stdlib.h> (no kidding!)
#define PointerSizeInt int64_t
#define PointerSizeUInt uint64_t

#define OPENMS_HAS_UNISTD_H
/* #undef OPENMS_HAS_PROCESS_H */
#define OPENMS_HAS_STDINT_H

#define OPENMS_HAS_TIME_H
#define OPENMS_HAS_SYS_TYPES_H
#define OPENMS_HAS_SYS_TIMES_H
#define OPENMS_HAS_SYS_TIME_H

#define OPENMS_HAS_KILL
#define OPENMS_HAS_SYSCONF

// library versions
#define OPENMS_LIBSVM_VERSION 3.1.2
#define OPENMS_LIBSVM_VERSION_MAJOR 3
#define OPENMS_LIBSVM_VERSION_MINOR 1

#define COINOR_SOLVER 0 


// class & TOPP tests
#define DB_PLUGIN "QMYSQL"
// Macro to construct a c string containing the complete path to the test data
#define OPENMS_GET_TEST_DATA_PATH(filename) (std::string("/build/buildd/openms-1.9.0/source/TEST/data/") + filename).c_str()
#define OPENMS_GET_TEST_DATA_PATH_MESSAGE(prefix,filename,suffix) (prefix + std::string("/build/buildd/openms-1.9.0/source/TEST/data/") + filename + suffix).c_str()


#endif // OPENMS_CONFIG_H
